@@ -265,6 +265,8 @@ def hanlp_jar_path(version):
 
 
 def uninstall_hanlp_jar(version='old'):
+    import jpype
+    jpype.shutdownJVM()
     if version == 'old':
         vs = hanlp_installed_jar_versions()
         if len(vs) > 1:
